use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Amazon::API::Object::MapperMWSProduct;
use Test::More;
use XML::LibXML;
use XML::LibXML::XPathContext;
use File::Slurp;

sub Main {
    testMapSubProducts();
    done_testing();
}

sub testMapSubProducts {
    my $XML = read_file('MWSParentProductResponse.xml');
    
    my $o = DE_EPAGES::Amazon::API::Object::MapperMWSProduct->new();
    is($o->{'STDURL'},'http://mws.amazonservices.com/schema/Products/2011-10-01/default.xsd','stdURL namespace URL');
    is($o->{'ANSURL'},'http://mws.amazonservices.com/schema/Products/2011-10-01','ansURL namespace URL');

    my $xpc = $o->initLibXML($XML);
    my $ValueNames = $o->_getSubProductAttributeNames($xpc); ## no critic qw(ProhibitPrivateSubroutineUse)
    is (ref $ValueNames,'ARRAY', 'Data type check');
    is ($ValueNames->[0],'Color','Color Element check');
    is ($ValueNames->[1],'Brand','Brand Element check');

    my $ValueArray = $o->_BuildDataSets($xpc,$ValueNames->[0]); ## no critic qw(ProhibitPrivateSubroutineUse)
    is (ref $ValueArray, 'HASH','Data type check');
    is ($ValueArray->{'Name'},'Color','get Element name');
    is (ref $ValueArray->{'Data'},'ARRAY','data Element type check');
    is ($ValueArray->{'Data'}->[0],'Color1','first Color tag check');
    is ($ValueArray->{'Data'}->[1],'Color2','second Color tag check');

    $ValueArray = $o->_BuildDataSets($xpc,$ValueNames->[1]); ## no critic qw(ProhibitPrivateSubroutineUse)
    is (ref $ValueArray, 'HASH','Data type check');
    is ($ValueArray->{'Name'},'Brand','get Element name');
    is (ref $ValueArray->{'Data'},'ARRAY','data Element type check');
    is ($ValueArray->{'Data'}->[0],'Brand1','first Brand tag check');
    is ($ValueArray->{'Data'}->[1],'Brand2','second Brand tag check');
    
    my $Assignment = $o->_BuildAssignmentHash($xpc); ## no critic qw(ProhibitPrivateSubroutineUse)
    is (ref $Assignment, 'HASH','Assignment Hash return data type check');
    is ($Assignment->{'Color1Brand1'},'66614','mapping case one');
    is ($Assignment->{'Color2Brand2'},'66616','mapping case two');

    my $aSubProduct = $o->_GetSubProducts($xpc); ## no critic qw(ProhibitPrivateSubroutineUse)
    is (ref $aSubProduct, 'HASH','_MapSubProducts return data type check');
    is (ref $aSubProduct->{'DataSets'},'ARRAY', 'DataSets is a array element');
    is (ref $aSubProduct->{'DataSets'}[0],'HASH', 'First DataSet element is a hash');
    is (ref $aSubProduct->{'DataSets'}[0]->{'Data'},'ARRAY', 'DataSets->Data is a array element');
    is ($aSubProduct->{'DataSets'}[0]->{'Data'}[0],'Color1', 'DataSets->Data first element');
    is ($aSubProduct->{'DataSets'}[0]->{'Data'}[1],'Color2', 'DataSets->Data Second element');
    is ($aSubProduct->{'DataSets'}[0]->{'Name'},'Color', 'DataSets name element');
    is ($aSubProduct->{'DataSets'}[1]->{'Data'}[0],'Brand1', 'DataSets->Data first element');
    is ($aSubProduct->{'DataSets'}[1]->{'Data'}[1],'Brand2', 'DataSets->Data Second element');
    is ($aSubProduct->{'DataSets'}[1]->{'Name'},'Brand', 'DataSets name element');
    is ($aSubProduct->{'Assignment'}{'Color1Brand1'},'66614', 'first Assignment');
    is ($aSubProduct->{'Assignment'}{'Color2Brand2'},'66616', 'second Assignment');
}

RunScript( Sub => \&Main );